#!/usr/bin/perl

# Author : Damien KROTKINE (dams@gentoo.org)
#
# Contributors : 
#
# Copyright (C) 2002-2005 Damien KROTKINE (dams@gentoo.org)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

=head1 NAME

PERL : Libconf::Glueconf::Networking::Hosts
C/PYTHON/RUBY : Networking/Hosts

=head1 DESCRIPTION

Libconf::Glueconf::Networking::Hosts is a template to handle /etc/hosts style files.

=head1 SYNOPSIS

  $hosts = new Libconf::Glueconf::Networking::Hosts({ filename => '/etc/hosts' });
  $hosts->{'127.0.0.1'}{aliases} = q(me myself I);
  $hosts->{'127.0.0.1'}{canonical_hostname} = '10calH0st';
  $hosts->write_conf();
  $hosts->write_conf('alternate_file);

=head1 CONSTRUCTOR

=over

=item B<new($options)>

creates the template

  $hosts = new Libconf::Glueconf::Networking::Hosts({
                                                      .. arguments .. 
                                                    })

the options are the same as in L<Libconf::Templates::Generic::KeyValues>, look
there to have the details.

=back

=head1 METHODS

See <Libconf::Glueconf> for general methods

=cut

package Libconf::Glueconf::Networking::Hosts;
use strict;
use Libconf::Templates;
use Libconf::Glueconf::System::Passwd;
use Libconf::Templates::Generic::KeyValues;

our @ISA = qw(Libconf::Glueconf::System::Passwd);

sub new {
    my ($class, $args) = @_;
    my $libconf = new Libconf::Templates::Generic::KeyValues(init_args($args, {
                                                                               regexp => '^\s*(\S+)\s+(\S+)\s+(.*?)\s*$',
                                                                               keys_list => [qw(IP_address canonical_hostname aliases)],
                                                                               identifier_key => 'IP_address',
                                                                               output_function => sub { my $atom = shift; join("\t", map { $atom->{values}{$_} } @_ ) },
                                                                              }));
    $libconf->read_conf();
    tie my %wrapper, 'Libconf::Glueconf::System::Passwd::Wrapper', $libconf;
    bless \%wrapper, $class;

}

sub description { 'template for the hosts (/etc/hosts) configuration file' }

1;
